<?php
/**
* Custom Hooks
*
* @package GridMini WordPress Theme
* @copyright Copyright (C) 2025 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridmini_before_header() {
    do_action('gridmini_before_header');
}

function gridmini_after_header() {
    do_action('gridmini_after_header');
}

function gridmini_before_main_content() {
    do_action('gridmini_before_main_content');
}
add_action('gridmini_before_main_content', 'gridmini_top_widgets', 20 );
add_action('gridmini_before_main_content', 'gridmini_top_left_right_widgets', 40 );

function gridmini_after_main_content() {
    do_action('gridmini_after_main_content');
}
add_action('gridmini_after_main_content', 'gridmini_bottom_widgets', 10 );

function gridmini_sidebar_one() {
    do_action('gridmini_sidebar_one');
}
add_action('gridmini_sidebar_one', 'gridmini_sidebar_one_widgets', 10 );

function gridmini_sidebar_two() {
    do_action('gridmini_sidebar_two');
}

function gridmini_before_single_post() {
    do_action('gridmini_before_single_post');
}

function gridmini_before_single_post_title() {
    do_action('gridmini_before_single_post_title');
}

function gridmini_after_single_post_title() {
    do_action('gridmini_after_single_post_title');
}

function gridmini_top_single_post_content() {
    do_action('gridmini_top_single_post_content');
}

function gridmini_bottom_single_post_content() {
    do_action('gridmini_bottom_single_post_content');
}

function gridmini_after_single_post_content() {
    do_action('gridmini_after_single_post_content');
}

function gridmini_after_single_post() {
    do_action('gridmini_after_single_post');
}

function gridmini_before_single_page() {
    do_action('gridmini_before_single_page');
}

function gridmini_before_single_page_title() {
    do_action('gridmini_before_single_page_title');
}

function gridmini_after_single_page_title() {
    do_action('gridmini_after_single_page_title');
}

function gridmini_after_single_page_content() {
    do_action('gridmini_after_single_page_content');
}

function gridmini_after_single_page() {
    do_action('gridmini_after_single_page');
}

function gridmini_before_comments() {
    do_action('gridmini_before_comments');
}

function gridmini_after_comments() {
    do_action('gridmini_after_comments');
}

function gridmini_before_footer() {
    do_action('gridmini_before_footer');
}

function gridmini_after_footer() {
    do_action('gridmini_after_footer');
}