<?php
/**
* Template part for displaying single posts.
*
* @link https://developer.wordpress.org/themes/basics/template-hierarchy/
*
* @package GridMini WordPress Theme
* @copyright Copyright (C) 2025 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/
?>

<?php gridmini_before_single_post(); ?>

<article id="post-<?php the_ID(); ?>" <?php post_class('gridmini-post-singular gridmini-box'); ?>>
<div class="gridmini-box-inside">

    <?php gridmini_before_single_post_title(); ?>

    <?php if ( !(gridmini_get_option('hide_post_title')) ) { ?>
    <header class="entry-header">
    <div class="entry-header-inside gridmini-clearfix">
        <?php if ( gridmini_get_option('remove_post_title_link') ) { ?>
            <?php the_title( '<h1 class="post-title entry-title">', '</h1>' ); ?>
        <?php } else { ?>
            <?php the_title( sprintf( '<h1 class="post-title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h1>' ); ?>
        <?php } ?>

        <?php gridmini_single_postmeta(); ?>
    </div>
    </header><!-- .entry-header -->
    <?php } ?>

    <?php gridmini_after_single_post_title(); ?>

    <div class="entry-content gridmini-clearfix">
            <?php
            gridmini_top_single_post_content();

            the_content( sprintf(
                wp_kses(
                    /* translators: %s: Name of current post. Only visible to screen readers */
                    __( 'Continue reading<span class="gridmini-sr-only"> "%s"</span> <span class="meta-nav">&rarr;</span>', 'gridmini' ),
                    array(
                        'span' => array(
                            'class' => array(),
                        ),
                    )
                ),
                wp_kses_post( get_the_title() )
            ) );

            wp_link_pages( array(
             'before'      => '<div class="gridmini-clearfix"></div><div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'gridmini' ) . '</span>',
             'after'       => '</div>',
             'link_before' => '<span>',
             'link_after'  => '</span>',
             ) );

            gridmini_bottom_single_post_content();
            ?>
    </div><!-- .entry-content -->

    <?php gridmini_after_single_post_content(); ?>

    <?php if ( !(gridmini_get_option('hide_author_bio_box')) ) { echo wp_kses_post( force_balance_tags( gridmini_add_author_bio_box() ) ); } ?>

    <?php if ( !(gridmini_get_option('hide_post_tags')) ) { ?>
    <?php if ( has_tag() ) { ?>
    <footer class="entry-footer gridmini-entry-footer">
    <div class="gridmini-entry-footer-inside">
        <?php gridmini_post_tags(); ?>
    </div>
    </footer><!-- .entry-footer -->
    <?php } ?>
    <?php } ?>

</div>
</article>

<?php gridmini_after_single_post(); ?>